@@ -4,13 +4,15 @@ Copyright 2021-2021 The jdh99 Authors. All rights reserved.
 Authors: jdh99 <jdh821@163.com>
 """
 
+import sys
+
 _file = None
 
 
 def _get_ch(ch):
     global _file
     if _file is None:
-        _file = open('/lib/ssd1306py/ascii16.txt', 'r')
+        _file = open(sys.path[1] + '/ssd1306py/ascii16.txt', 'r')
 
     _file.seek(ord(ch) * 86)
     get_line = _file.readline()
